<?php
/**
 * Class for handle ajax request
 */
if ( ! class_exists( 'IPSitno_Ajax' )) {

    class IPSitno_Ajax
    {
        /**
         * Take ajax action name
         *
         * @var string
         */
        protected $_action;
        
        /**
         * Take ajax action handlers
         *
         * @var array
         */
        protected $_handlers = array(
            'ipsitno_update'            => 'update',
            'ipsitno_delete'            => 'delete',
            'ipsitno_setting'           => 'setting',
            'ipsitno_get_preview'       => 'get_preview'
        );
        
        /**
         * Class constructor
         *
         * @return void
         */
        public function __construct()
        {
        }
        
        /**
         * Get action name
         *
         * @return string
         */
        public function getAction()
        {
            return $this->_action;
        }
        
        /**
         * Set action
         *
         * @param  string $action
         * @return IPShortcode_Ajax
         */
        public function setAction( $action )
        {
            $this->_action = sanitize_title( $action );
        }
        
        /**
         * Execute request
         *
         * @param  string $action
         * @return IPShortcode_Ajax
         */
        public function exec()
        {
            $data = array_merge( $_GET, $_POST );
            if ( empty( $data['doajax'] ) || empty( $data['ipsitno'] ) || empty( $data['action'] ) ) {
                return true;
            }
            $this->setAction( $data['action'] );
            
            $action   = $this->getAction();
            $handlers = (array)$this->_handlers;
            if ( array_key_exists( $action, $handlers )) {
                $handler = $handlers[$action];
                if ( method_exists( $this, $handler )) {
                    $this->$handler();
                }
            }
            return true;
        }
        
        /**
         * Update
         *
         * @return void
         */
        public function update()
        {
            $redirect = false;
            $is_add   = false;
            $error    = true;
            if ( ! empty( $_POST['isadd'] )) {
                $is_add = true;
            }
            if ( ! empty( $_POST['shareid'] )) {
                $shareId = absint( $_POST['shareid'] );
                if ( $share = get_post( $shareId ) ) {
                    $this->_update_share( $share );
                } else {
                    $shareId = 0;
                }
            } else {
                $shareId = $this->_add_share();
            }
            if ( $shareId )
            {
                $error = false;
                $model = new IPSitno_Model();
                $model->save_setting( $shareId );
            }
            if ( $error ) {
                $status  = 0;
                $shareId  = 0;
                if ( $is_add ) {
                    $message = __( 'Failed to create a share page.', 'wp_share_it_now' );
                } else {
                    $message = __( 'Failed to save share page.', 'wp_share_it_now' );
                }
            } else {
                $status = 1;
                if ( $is_add ) {
                    $message  = __( 'Successfully create a share page.', 'wp_share_it_now' );
                    $redirect = admin_url() . 'admin.php?page=ipsitno&create=1';
                } else {
                    $message = __( 'Successfully to save share page.', 'wp_share_it_now' );
                }
            }
            $result = array(
                'status'   => $status,
                'message'  => $message,
                'shareid'  => $shareId
            );
            if ( $redirect ) {
                $result['redirect'] = $redirect;
            }
            echo json_encode( $result );
            die();
        }
        
        /**
         * Add new share page
         *
         * @return int
         */
        protected function _add_share()
        {
            global $user_ID;
            
            if ( empty( $_POST['name'] )) {
                $title = 'Unknown';
            } else {
                $title = apply_filters( 'single_post_title', $_POST['name'] );
            }
            if ( $_POST['status'] == 'true' ) {
                $status = 'publish';
            } else {
                $status = 'draft';
            }
            $dataPost = array(
                'post_status'  => $status, 
                'post_type'    => 'ipsitno-item', 
                'post_author'  => $user_ID,
                'post_title'   => $title,
                'post_content' => ''
            );
            $result = wp_insert_post( $dataPost );
            return $result;
        }
        
        /**
         * Update share page
         *
         * @param  object $share
         * @return boolean
         */
        protected function _update_share( $share )
        {
            $result   = 0;
            $dataPost = array();
            if ( ! empty( $_POST['name'] ) && $_POST['name'] != $share->post_title ) {
                $dataPost['post_title'] = apply_filters( 'single_post_title', $_POST['name'] );
            }
            if ( $_POST['status'] == 'true' ) {
                $status = 'publish';
            } else {
                $status = 'draft';
            }
            if ( $status != $share->post_status ) {
                $dataPost['post_status'] = $status;
            }
            if ( ! empty( $dataPost )) {
                $dataPost['ID'] = $share->ID;
                $result = wp_update_post( $dataPost );
            }
            return $result;
        }
        
        /**
         * Processing ajax for delete object
         *
         * @return void
         */
        public function delete()
        {
            $item = false;
            if ( ! empty( $_REQUEST['id'] )) {
                $id   = absint( $_REQUEST['id'] );
                $item = get_post( $id );
            }
            if ( ! $item ) {
                echo json_encode( array(
                    'status'   => 0,
                    'message'  => __( 'Error system', 'wp_share_it_now' )
                ) );
                die();
            }
            $result = wp_delete_post( $item->ID, true );
            if ( $result ) {
                echo json_encode( array(
                    'status'   => 1,
                    'message'  => __( 'Successfully remove the share object', 'wp_share_it_now' ),
                    'redirect' => admin_url() . 'admin.php?page=ipsitno&delete=1'
                ) );
            } else {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to remove the share object', 'wp_share_it_now' )
                ) );
            }
            die();
        }
        
        /**
         * Get preview
         *
         * @return void
         */
        public function get_preview()
        {
            //Create object setting
            $setting = new IPSitno_Setting( 0, '__ipsitno-setting' );
            $setting->addSettings( $_POST );
            
            //Create preview
            $factory = new IPSitno_Factory( $setting );
            $factory->render();
            die();
        }
        
        /**
         * Processing ajax for save setting
         *
         * @return void
         */
        public function setting()
        {
            $error = false;
            if ( isset( $_POST['home_share'] )) {
                $this->_save_setting( 'home_share' );
            }
            if ( isset( $_POST['general_share'] )) {
                $this->_save_setting( 'general_share' );
            }
            if ( $error ) {
                $status = 0;
                $msg    = __( 'Failed to update share settings.', 'wp_share_it_now' );
            } else {
                $status = 1;
                $msg    = __( 'Successfully to update share settings.', 'wp_share_it_now' );
            }
            echo json_encode( array(
                'status'    => $status,
                'message'   => $msg
            ) );
            die();
        }
        
        /**
         * Save setting
         *
         * @param  string $name
         * @return boolean
         */
        protected function _save_setting( $name )
        {
            if ( ! empty( $_POST[$name] ))
            {
                $shareId = absint( $_POST[$name] );
                if ( $share = get_post( $shareId ))
                {
                    update_option( '__ipsitno_' . $name, $shareId );
                }
            } else {
                update_option( '__ipsitno_' . $name, 0 );
            }
            return true;
        }
    }
}