<?php
if ( ! class_exists( 'IPSitno_Factory' )) {

    /**
     * Class for create share
     */
    class IPSitno_Factory
    {
        /**
         * Share Object
         *
         * @var object
         */
        protected $_share;
        
        /**
         * Share Object setting
         *
         * @var object
         */
        protected $_setting;
         
        /**
         * Class construct
         *
         * @return void
         */
        public function __construct( $setting = false )
        {
            if ( ! $setting ) 
            {
                $shareId = 0;
                if ( $share = $this->_get_share_object() ) {
                    $shareId = $share->ID;
                }
                $this->_share     = $share;
                $this->_setting   = new IPSitno_Setting( $shareId, '__ipsitno-setting' );
                $this->_is_show   = $this->_is_show();
            } else {
                $this->_setting   = $setting;
                $this->_is_show   = true;
            }
            $this->_post_open = false;
        }
        
        /**
         * Get setting
         *
         * @return object
         */
        public function setting()
        {
            return $this->_setting;
        }
        
        /**
         * Is show
         *
         * @return object
         */
        public function is_show()
        {
            return $this->_is_show;
        }
        
        /**
         * Render share
         *
         * @return void
         */
        public function render()
        {
            if ( ! $this->is_show() ) {
                return false;
            }
            $share = $this->_get_share();
            $share = $this->_get_container( $share );
            
            echo $share;
        }
        
        /**
         * Get share
         *
         * @return string
         */
        protected function _get_share()
        {
            $share  = $this->_get_tab();
            $share .= $this->_get_content();
            return $share;
        }
        
        /**
         * Get tab button
         *
         * @return string
         */
        protected function _get_tab()
        {
            $st    = $this->_setting;
            $icon  = $st->getSetting( 'button_tab_icon', 'shopping-cart' );
            $label = $st->getSetting( 'button_tab_label' );
            $bg    = $st->getSetting( 'tab_bg_color', '#cccccc' );
            $color = $st->getSetting( 'tab_color', '#333333' );
            $tab   = '<div class="ipsitno-tab" style="background-color:'.$bg.';color:'.$color.';">' .
                        '<a href="#" style="color:'.$color.';">' . 
                            '<i class="ibe ibe-' . $icon . '"></i>' . 
                            '<strong class="ipsitno-tab-label">' . $label . '</strong>' .
                        '</a>' .
                   '</div>';
            return $tab;
        }
        
        /**
         * Get main content
         *
         * @return string
         */
        protected function _get_content()
        {
            $st     = $this->_setting;
            $style  = ' style="';
            $style .= 'background-color:' . $st->getSetting( 'bg_color', '#ffffff' ) . ';';
            
            $border  = $st->getSetting( 'border_width', 1 ) . 'px solid';
            $border .= $st->getSetting( 'border_color', '#cccccc' );
            $style  .= 'border:' . $border . ';';
            $style  .= '"';
            
            $loader  = IPSITNO_BASE_URL . '/img/loading.gif';
            
            $content = '<div class="ipsitno-main">' .
                            '<div class="ipsitno-main-inner">' .
                                '<div class="ipsitno-main-style"' . $style . '>' .
                                    '<div class="ipsitno-content">' .
                                        $this->_get_pre_content() .
                                        $this->_get_post_content() .
                                    '</div>' .
                                    $this->_get_footer() .
                                    '<div class="ipsitno-loader" style="display:none;"><img src="'.$loader.'"></div>' .
                                '</div>' .
                            '</div>' .
                       '</div>';
            return $content;
        }
        
        /**
         * Get footer content
         *
         * @return string
         */
        protected function _get_footer()
        {
            $st     = $this->_setting;
            $style  = ' style="';
            $style .= 'background-color:' . $st->getSetting( 'footer_bg_color', '#e1e1e1' ) . ';';
            $style .= 'color:' . $st->getSetting( 'footer_color', '#888888' ) . ';';
            $style  .= '"';
            $content = '<div class="ipsitno-footer">' .
                            '<div class="ipsitno-footer-style"' . $style . '>' .
                                '<p>' . $st->getSetting( 'footer_info' ) . '</p>' .
                            '</div>' .
                       '</div>';
            return $content;
        }
        
        /**
         * Get pre content
         *
         * @return string
         */
        protected function _get_pre_content()
        {
            $dsp = '';
            if ( $this->_post_open ) {
                $dsp = ' style="display:none;"';
            }
            $st      = $this->_setting;
            $ticolor = $st->getSetting( 'title_color', '#222222' );
            $txcolor = $st->getSetting( 'text_color', '#444444' );
            $content = '<div class="ipsitno-pre-content"' . $dsp . '>' .
                            '<div class="ipsitno-pre-title">' .
                                '<h2 style="color:' . $ticolor . ';">' . $st->getSetting( 'pre_title' ) . '</h2>' .
                                '<h3 style="color:' . $txcolor . ';">' . $st->getSetting( 'pre_info' ) . '</h3>' .
                            '</div>' .
                            $this->_get_pre_image() .
                            $this->_get_pre_share() .
                       '</div>';
            return $content;
        }
        
        /**
         * Get pre content image
         *
         * @return string
         */
        protected function _get_pre_image()
        {
            $st  = $this->_setting;
            $src = false;
            $content = '';
            if ( $imgid = $st->getSetting( 'pre_image' )) 
            {
                $data = wp_get_attachment_image_src( $imgid, 'full' );
                if ( ! empty( $data[0] )) {
                    $src = $data[0];
                }
            }
            if ( $src )
            {
                $content = '<div class="ipsitno-pre-image">' .
                                '<img src="' . $src . '" alt="">' .
                           '</div>';
            }
            return $content;
        }
        
        /**
         * Get pre share button
         *
         * @return string
         */
        protected function _get_pre_share()
        {
            $st       = $this->_setting;
            $txcolor  = $st->getSetting( 'text_color', '#444444' );
            $content  = '<div class="ipsitno-pre-share">';
            $content .= '<p class="ipsitno-pre-share-info" style="color:' . $txcolor . ';">' . $st->getSetting( 'button_share_info' ) . '</p>';
            $socials  = array(
                'facebook',
                'twitter',
                'google-plus'
            );
            $style = $st->getSetting( 'share_button_style', 1 );
            $root  = IPSITNO_BASE_URL . '/img/button/button-' . $style . '/';
            foreach( $socials as $social )
            {
                if ( $st->getSetting( 'share_' . $social, 'on' ) == 'on' ) 
                {
                    $icon = $root . $social . '.png';
                    $link = $this->_get_share_link( $social );
                    
                    $content .= '<a href="' . $link . '" class="ipsitno-share ipsitno-share-' . $social . '">' . 
                                    '<img src="' . $icon . '" alt="' . $social . '">' .
                                '</a>';
                }
            }
            $content .= '</div>';
            return $content;
        }
        
        /**
         * Get post content
         *
         * @param  string $type
         * @return string
         */
        protected function _get_share_link( $type )
        {
            if ( ! $pageurl = $this->_setting->getSetting( 'page_url' ) ) {
                $pageurl = $this->_get_page_url();
            }
            $pageurl = urlencode( $pageurl );
            if ( ! $pagetitle = $this->_setting->getSetting( 'page_title' ) ) {
                $pagetitle = $this->_get_page_title();
            }
            $pagetitle = urlencode( $pagetitle );
            
            $actions =  array(
                'facebook'      => 'http://www.facebook.com/share.php?u=' . $pageurl . '&title=' . $pagetitle,
                'twitter'       => 'https://twitter.com/share?url=' . $pageurl . '&text=' . $pagetitle,
                'google-plus'   => 'https://plusone.google.com/_/+1/confirm?hl=en&url=' . $pageurl . '&title=' . $pagetitle
            );
            $link = '#';
            if ( array_key_exists( $type, $actions )) {
                $link = $actions[$type];
            }
            return $link;
        }
        
        /**
         * Get page url
         *
         * @return void
         */
        protected function _get_page_url()
        {
            global $post;
            
            $link = '#';
            if ( $post ) {
                $link = get_permalink( $post );
            }
            return $link;
        }
        
        /**
         * Get page title
         *
         * @return void
         */
        protected function _get_page_title()
        {
            global $post;
            
            $title = '';
            if ( $post ) {
                $title = $post->post_title;
            }
            return $title;
        }
        
        /**
         * Get post content
         *
         * @return string
         */
        protected function _get_post_content()
        {
            $dsp = '';
            if ( ! $this->_post_open ) {
                $dsp = ' style="display:none;"';
            }
            $st      = $this->_setting;
            $ticolor = $st->getSetting( 'title_color', '#444444' );
            $content = '<div class="ipsitno-post-content"' . $dsp . '>' .
                            '<div class="ipsitno-post-title">' .
                                '<h2 style="color:'.$ticolor.';">' . $st->getSetting( 'success_text' ) . '</h2>' .
                                '<h3 style="color:' . $ticolor . ';">' . $st->getSetting( 'success_info' ) . '</h3>' .
                            '</div>' .
                            $this->_get_success_url() .
                       '</div>';
            return $content;
            return $content;
        }
        
        /**
         * Get post image
         *
         * @return string
         */
        protected function _get_success_url()
        {
            $st  = $this->_setting;
            $src = false;
            $content = '';
            if ( $imgid = $st->getSetting( 'post_image' )) 
            {
                $data = wp_get_attachment_image_src( $imgid, 'full' );
                if ( ! empty( $data[0] )) {
                    $src = $data[0];
                }
            }
            $url = $st->getSetting( 'success_url', '#' );
            if ( $src ) {
                $content = '<div class="ipsitno-post-image">' .
                                '<a href="' . $url . '">' .
                                    '<img src="' . $src . '" alt="">' .
                                '</a>' .
                           '</div>';
            } else {
                $content = '<div class="ipsitno-post-url">' .
                                '<a href="' . $url . '">' . $url . '</a>' .
                           '</div>';
            }
            return $content;
        }
        
        /**
         * Get container share
         *
         * @return string
         */
        protected function _get_container( $share )
        {
            $st     = $this->_setting;
            $ff     = $st->getSetting( 'font_family', 'roboto' );
            $family = IPSitno_Font::getFamily( $ff );
            
            $style  = ' style="';
            $style .= 'font-family:' . $family . ';';
            $style .= '"';
            $class = $this->_get_class();
            //Background overlay
            if ( $st->getSetting( 'background_overlay', 'true' ) == 'true' ) {
                $cov .= ' ipsitno-overlay-on';
            } else {
                $cov .= ' ipsitno-overlay-off';
            }
            //First Load 
            $cov   .= ' ipsitno-close';
            $scroll = $st->getSetting( 'scroll_show', 0 );
            $cont   = '<div id="ipsitno-root" data-share="' . $this->_share->ID . '"' . $style . ' class="' . $cov . '">' .
                        '<div id="ipsitno-style"' . $class . ' data-speed="md" data-scroll="' . $scroll . '">' .
                            '<div id="ipsitno-inner">' .
                                $share .
                            '</div>' .
                        '</div>' .
                        $this->_get_audio() . 
                        '<div class="ipsitno-overlay"></div>' .
                    '</div>';
            return $cont;
        }
        
        /**
         * Get class
         *
         * @return string
         */
        protected function _get_class()
        {
            $st     = $this->_setting;
            $class  = ' class="';
            //Position
            $posit  = $st->getSetting( 'position', 'right' );
            $class .= 'ipsitno-position-' . $posit;
            
            //Scroll show
            $class .= ' ipsitno-scroll-off';
            //Font size
            $size = $st->getSetting( 'font_size', 'md' );
            $class .= ' ipsitno-font-' . $size;
            
            $class .= '"';
            return $class;
        }
        
        /**
         * Get share object
         *
         * @return object
         */
        protected function _get_share_object()
        {
            global $post;
            
            $shareId = 0;
            $share   = false;
            $general = 0;
            if ( ! empty( $general )) {
                $shareId = absint( $general );
            } else 
            {
                if ( ( is_page() || is_single() ) && ! empty( $post )) {
                    $shareId = get_post_meta( $post->ID, '__ipsitno_page_share', true );
                } elseif ( is_home() ) {
                    $shareId = get_option( '__ipsitno_home_share' );
                }
            }
            if ( ! empty( $shareId )) {
                $share = get_post( $shareId );
            }
            return $share;
        }
        
        /**
         * Check is share object showing
         *
         * @return object
         */
        protected function _is_show()
        {
            if ( ! $this->_share || $this->_share->post_status != 'publish' ) {
                return false;
            }
            if ( ! $this->_check_lifetime() ) {
                return false;
            }
            return true;
        }
        
        /**
         * Check wheater post content is open
         *
         * @return object
         */
        protected function _is_post_open()
        {
            $open = false;
            $opt  = $this->_setting->getSetting( 'cookie', 'true' );
            if ( $opt == 'true' && ! empty( $_COOKIE['_ipsitno_post_open'] )) {
                $open = true;
            }
            return $open;
        }
        
        /**
         * Check lifetime of share object
         *
         * @return object
         */
        protected function _check_lifetime()
        {
            if ( ! $lifetime = $this->_setting->getSetting( 'lifetime' ) ) {
                return true;
            }
            $datatime = explode( '-', $lifetime );
            if ( empty( $datatime ) || count( $datatime ) < 2 ) {
                return true;
            }
            $start = array_shift( $datatime );
            $end   = array_shift( $datatime );
            
            $tstart = strtotime( $start );
            $tend   = strtotime( $end );
            $tnow   = time();
            
            if ( $tnow < $tend && $tnow > $tstart ) {
                return true;
            }
            return false;
        }
        
        /**
         * Get audio
         *
         * @param  object  $setting
         * @return string
         */
        protected function _get_audio()
        {
            $st    = $this->_setting;
            $audio = '';
            $aid   = $st->getSetting( 'audio', '0' );
            if ( $aid != 0 )
            {
                $base   = IPSITNO_BASE_URL . 'audio/audio-' . $aid;
                $audio .= '<audio class="ipsitno-audio">' .
                            '<source src="' . $base . '.mp3" type="audio/mpeg">' .
                            '<source src="' . $base . '.ogg" type="audio/ogg">' .
                            __( 'Your browser does not support this audio format.', 'wp-share-it-now' ) .
                           '</audio>';
            }
            return $audio;
        }
    }
}